<?php
namespace wcf\system\box;
use wcf\system\cache\builder\InviteTopMembersBoxCacheBuilder;
use wcf\system\cache\runtime\UserProfileRuntimeCache;
use wcf\system\request\LinkHandler;
use wcf\system\WCF;

/**
 * Shows users with the most invites.
 *
 * @author		Udo Zaydowicz
 * @copyright	2016-2020 Zaydowicz.de
 * @license		Zaydowicz Commercial License <https://zaydowicz.de>
 * @package		com.uz.wcf.invitation
 */
class InviteTopMembersBoxController extends AbstractBoxController {
	/**
	 * @inheritDoc
	 */
	protected static $supportedPositions = ['sidebarLeft', 'sidebarRight'];
	
	/**
	 * @inheritDoc
	 */
	public function hasLink() {
		return MODULE_MEMBERS_LIST == 1;
	}
	
	/**
	 * @inheritDoc
	 */
	public function getLink() {
		if (MODULE_MEMBERS_LIST) {
			$parameters = 'sortField=invites&sortOrder=DESC';
			
			return LinkHandler::getInstance()->getLink('MembersList', [], $parameters);
		}
		
		return '';
	}
	
	/**
	 * @inheritDoc
	 */
	protected function loadContent() {
		if (MODULE_INVITE) {
			$userIDs = InviteTopMembersBoxCacheBuilder::getInstance()->getData();
			
			if (!empty($userIDs)) {
				$userProfiles = UserProfileRuntimeCache::getInstance()->getObjects($userIDs);
				
				WCF::getTPL()->assign([
						'userProfiles' => $userProfiles
				]);
				$this->content = WCF::getTPL()->fetch('boxInviteTopMembers');
			}
		}
	}
}
